package com.example.hangry;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/api/ingredients")
public class IngredientController {

    @Autowired
    private IngredientService ingredientService;

    // 1. Globale Zutaten abrufen
    @GetMapping("/global")
    public ResponseEntity<List<Ingredient>> getGlobalIngredients() {
        List<Ingredient> ingredients = ingredientService.getGlobalIngredients();
        return ResponseEntity.ok(ingredients);
    }

    // 2. Benutzerdefinierte Zutaten abrufen
    @GetMapping("/user/{userId}")
    public ResponseEntity<List<Ingredient>> getUserIngredients(@PathVariable Long userId) {
        List<Ingredient> ingredients = ingredientService.getUserIngredients(userId);
        return ResponseEntity.ok(ingredients);
    }

    // 3. Neue globale Zutat hinzufügen
    @PostMapping("/global")
    public ResponseEntity<Ingredient> addGlobalIngredient(@RequestBody Ingredient ingredient) {
        Ingredient newIngredient = ingredientService.addGlobalIngredient(ingredient);
        return ResponseEntity.status(HttpStatus.CREATED).body(newIngredient);
    }

    // 4. Benutzerdefinierte Zutat hinzufügen
    @PostMapping("/user/{userId}")
    public ResponseEntity<Ingredient> addUserIngredient(
            @PathVariable Long userId,
            @RequestBody Ingredient ingredient
    ) {
        Ingredient newIngredient = ingredientService.addUserIngredient(userId, ingredient);
        return ResponseEntity.status(HttpStatus.CREATED).body(newIngredient);
    }

    // 5. Einzelne Zutat abrufen
    @GetMapping("/{id}")
    public ResponseEntity<Ingredient> getIngredientById(@PathVariable Long id) {
        Optional<Ingredient> ingredient = ingredientService.getIngredientById(id);
        if (ingredient.isPresent()) {
            return ResponseEntity.ok(ingredient.get());
        } else {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).build();
        }
    }

    // 6. Zutat aktualisieren
    @PutMapping("/{id}")
    public ResponseEntity<Ingredient> updateIngredient(
            @PathVariable Long id,
            @RequestBody Ingredient updatedIngredient
    ) {
        Optional<Ingredient> ingredient = ingredientService.updateIngredient(id, updatedIngredient);
        if (ingredient.isPresent()) {
            return ResponseEntity.ok(ingredient.get());
        } else {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).build();
        }
    }

    // 7. Zutat löschen
    @DeleteMapping("/{id}")
    public ResponseEntity<Void> deleteIngredient(@PathVariable Long id) {
        boolean deleted = ingredientService.deleteIngredient(id);
        if (deleted) {
            return ResponseEntity.status(HttpStatus.NO_CONTENT).build();
        } else {
            return ResponseEntity.status(HttpStatus.NOT_FOUND).build();
        }
    }
}

