package com.example.hangry;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class IngredientService {

    @Autowired
    private IngredientRepository ingredientRepository;

    @Autowired
    private UserRepository userRepository;

    // 1. Globale Zutaten abrufen
    public List<Ingredient> getGlobalIngredients() {
        return ingredientRepository.findByIsGlobal(true);
    }

    // 2. Benutzerdefinierte Zutaten abrufen
    public List<Ingredient> getUserIngredients(Long userId) {
        Optional<User> user = userRepository.findById(userId);
        if (user.isPresent()) {
            return ingredientRepository.findByUserId(userId);
        } else {
            throw new IllegalArgumentException("User not found with ID: " + userId);
        }
    }

    // 3. Neue globale Zutat hinzufügen
    public Ingredient addGlobalIngredient(Ingredient ingredient) {
        ingredient.setGlobal(true); // Markiere die Zutat als global
        return ingredientRepository.save(ingredient);
    }

    // 4. Benutzerdefinierte Zutat hinzufügen
    public Ingredient addUserIngredient(Long userId, Ingredient ingredient) {
        Optional<User> user = userRepository.findById(userId);
        if (user.isPresent()) {
            ingredient.setGlobal(false); // Markiere die Zutat als benutzerspezifisch
            ingredient.setUser(user.get());
            return ingredientRepository.save(ingredient);
        } else {
            throw new IllegalArgumentException("User not found with ID: " + userId);
        }
    }

    // 5. Einzelne Zutat abrufen
    public Optional<Ingredient> getIngredientById(Long id) {
        return ingredientRepository.findById(id);
    }

    // 6. Zutat aktualisieren
    public Optional<Ingredient> updateIngredient(Long id, Ingredient updatedIngredient) {
        Optional<Ingredient> ingredient = ingredientRepository.findById(id);
        if (ingredient.isPresent()) {
            Ingredient existingIngredient = ingredient.get();
            existingIngredient.setName(updatedIngredient.getName());
            existingIngredient.setUnit(updatedIngredient.getUnit());
            return Optional.of(ingredientRepository.save(existingIngredient));
        } else {
            return Optional.empty();
        }
    }

    // 7. Zutat löschen
    public boolean deleteIngredient(Long id) {
        Optional<Ingredient> ingredient = ingredientRepository.findById(id);
        if (ingredient.isPresent()) {
            ingredientRepository.deleteById(id);
            return true;
        } else {
            return false;
        }
    }
}


